Insert a 'good enough' R script header
ger_headr.RdInsert a script header at the cursor in RStudio or Positron. The header includes sections for what the code creates, who the author is, the license, and the version.
ger_headr.RdInsert a script header at the cursor in RStudio or Positron. The header includes sections for what the code creates, who the author is, the license, and the version.