Get the root folder of your project
ger_root.RdFind the project root by looking upwards for an .Rproj file, an R
package DESCRIPTION, a .git folder, or a .here file (so it works in
both RStudio and Positron).
ger_root.RdFind the project root by looking upwards for an .Rproj file, an R
package DESCRIPTION, a .git folder, or a .here file (so it works in
both RStudio and Positron).