Skip to contents

Insert a script header at the cursor in RStudio or Positron. The header includes sections for what the code creates, who the author is, the license, and the version.

Usage

grp_headr()

Value

the header text (invisibly)

Examples

# with RStudio or Positron running:
# grp_headr()