Get the root folder of your project
grp_root.RdFind the project root by looking upwards for an .Rproj file, an R
package DESCRIPTION, a .git folder, or a .here file (so it works in
both RStudio and Positron).
grp_root.RdFind the project root by looking upwards for an .Rproj file, an R
package DESCRIPTION, a .git folder, or a .here file (so it works in
both RStudio and Positron).