Good enough data folders
ger_data.RdCreate the data folders and a data.md file:
- data-raw/
code used to import, download and include data in your project
- data/
processed, intermediate, or otherwise altered data in your project
- inst/extdata/
external data used for examples or testing
- data.md
document your data here and in
R/data.R