Good enough R setup files
ger_setup.RdCreate start-up files for a project (changelog.md, CITATION,
requirements.md, and LICENSE). Existing files are not overwritten.
- changelog.md
Manually document changes to the files or folders in your project.
- CITATION
Information and example of how to cite your project.
- requirements.md
Advice on how to manually list the requirements for your project.
- LICENSE
The CC0 1.0 license.