Insert an R script section header
grp_sect.RdInsert a section header at the cursor in RStudio or Positron (similar to
Cmd/Ctrl + Shift + R). Use level to nest sections in the document
outline.
grp_sect.RdInsert a section header at the cursor in RStudio or Positron (similar to
Cmd/Ctrl + Shift + R). Use level to nest sections in the document
outline.